@@ -73,7 +73,7 @@ class ReceivingBatchViews(APIBatchView):
         data['invoice_total'] = batch.invoice_total
         data['invoice_total_calculated'] = batch.invoice_total_calculated
 
-        data['can_auto_receive'] = self.handler.can_auto_receive(batch)
+        data['can_auto_receive'] = self.batch_handler.can_auto_receive(batch)
 
         return data
 
@@ -89,7 +89,7 @@ class ReceivingBatchViews(APIBatchView):
         a pending batch.
         """
         batch = self.get_object()
-        self.handler.auto_receive_all_items(batch)
+        self.batch_handler.auto_receive_all_items(batch)
         return self._get(obj=batch)
 
     def mark_receiving_complete(self):
@@ -119,7 +119,7 @@ class ReceivingBatchViews(APIBatchView):
         if not vendor:
             return {'error': "Vendor not found"}
 
-        purchases = self.handler.get_eligible_purchases(
+        purchases = self.batch_handler.get_eligible_purchases(
             vendor, self.enum.PURCHASE_BATCH_MODE_RECEIVING)
 
         purchases = [self.normalize_eligible_purchase(p)
@@ -128,10 +128,10 @@ class ReceivingBatchViews(APIBatchView):
         return {'purchases': purchases}
 
     def normalize_eligible_purchase(self, purchase):
-        return self.handler.normalize_eligible_purchase(purchase)
+        return self.batch_handler.normalize_eligible_purchase(purchase)
 
     def render_eligible_purchase(self, purchase):
-        return self.handler.render_eligible_purchase(purchase)
+        return self.batch_handler.render_eligible_purchase(purchase)
 
     @classmethod
     def defaults(cls, config):
@@ -321,6 +321,10 @@ class ReceivingBatchRowViews(APIBatchRowView):
         data['cases_expired'] = row.cases_expired
         data['units_expired'] = row.units_expired
 
+        cases, units = self.batch_handler.get_unconfirmed_counts(row)
+        data['cases_unconfirmed'] = cases
+        data['units_unconfirmed'] = units
+
         data['po_unit_cost'] = row.po_unit_cost
         data['po_total'] = row.po_total
 
@@ -328,7 +332,7 @@ class ReceivingBatchRowViews(APIBatchRowView):
         data['invoice_total'] = row.invoice_total
         data['invoice_total_calculated'] = row.invoice_total_calculated
 
-        data['allow_cases'] = self.handler.allow_cases()
+        data['allow_cases'] = self.batch_handler.allow_cases()
 
         data['quick_receive'] = self.rattail_config.getbool(
             'rattail.batch', 'purchase.mobile_quick_receive',
@@ -346,8 +350,8 @@ class ReceivingBatchRowViews(APIBatchRowView):
                 raise NotImplementedError("TODO: add CS support for quick_receive_all")
             else:
                 data['quick_receive_uom'] = data['unit_uom']
-                accounted_for = self.handler.get_units_accounted_for(row)
-                remainder = self.handler.get_units_ordered(row) - accounted_for
+                accounted_for = self.batch_handler.get_units_accounted_for(row)
+                remainder = self.batch_handler.get_units_ordered(row) - accounted_for
 
                 if accounted_for:
                     # some product accounted for; button should receive "remainder" only
@@ -389,7 +393,7 @@ class ReceivingBatchRowViews(APIBatchRowView):
                                                      default=False)
         if alert_received:
             data['received_alert'] = None
-            if self.handler.get_units_confirmed(row):
+            if self.batch_handler.get_units_confirmed(row):
                 msg = "You have already received some of this product; last update was {}.".format(
                     humanize.naturaltime(app.make_utc() - row.modified))
                 data['received_alert'] = msg
@@ -418,7 +422,7 @@ class ReceivingBatchRowViews(APIBatchRowView):
         # handler takes care of the row receiving logic for us
         kwargs = dict(form.validated)
         del kwargs['row']
-        self.handler.receive_row(row, **kwargs)
+        self.batch_handler.receive_row(row, **kwargs)
 
         self.Session.flush()
         return self._get(obj=row)
