@@ -64,6 +64,21 @@ def csrf_token(request, name='_csrf'):
     return HTML.tag("div", tags.hidden(name, value=token), style="display:none;")
 
 
+def get_form_data(request):
+    """
+    Returns the effective form data for the given request.  Mostly
+    this is a convenience, to return either POST or JSON depending on
+    the type of request.
+    """
+    # nb. we prefer JSON only if no POST is present
+    # TODO: this seems to work for our use case at least, but perhaps
+    # there is a better way?  see also
+    # https://docs.pylonsproject.org/projects/pyramid/en/latest/api/request.html#pyramid.request.Request.is_xhr
+    if request.is_xhr and not request.POST:
+        return request.json_body
+    return request.POST
+
+
 def should_use_buefy(request):
     """
     Returns a flag indicating whether or not the current theme supports (and
