@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -27,7 +27,7 @@ Pyramid Views
 from __future__ import unicode_literals, absolute_import
 
 from .core import View
-from .master import MasterView
+from .master import MasterView, ViewSupplement
 
 
 def includeme(config):
