@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -38,6 +38,7 @@ class BrandView(MasterView):
     model_class = model.Brand
     has_versions = True
     bulk_deletable = True
+    results_downloadable = True
     supports_autocomplete = True
 
     mergeable = True
@@ -135,5 +136,12 @@ class BrandView(MasterView):
         self.Session.delete(removing)
 
 
-def includeme(config):
+def defaults(config, **kwargs):
+    base = globals()
+
+    BrandView = kwargs.get('BrandView', base['BrandView'])
     BrandView.defaults(config)
+
+
+def includeme(config):
+    defaults(config)
