@@ -340,5 +340,12 @@ class CommonView(View):
                         permission='admin')
 
 
-def includeme(config):
+def defaults(config, **kwargs):
+    base = globals()
+
+    CommonView = kwargs.get('CommonView', base['CommonView'])
     CommonView.defaults(config)
+
+
+def includeme(config):
+    defaults(config)
