@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2020 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -45,5 +45,12 @@ class CreateCustomerOrderBatchView(CustomerOrderBatchView):
     creatable = False
 
 
-def includeme(config):
+def defaults(config, **kwargs):
+    base = globals()
+
+    CreateCustomerOrderBatchView = kwargs.get('CreateCustomerOrderBatchView', base['CreateCustomerOrderBatchView'])
     CreateCustomerOrderBatchView.defaults(config)
+
+
+def includeme(config):
+    defaults(config)
