@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -566,5 +566,12 @@ class CustomerOrderItemView(MasterView):
 CustomerOrderItemsView = CustomerOrderItemView
 
 
-def includeme(config):
+def defaults(config, **kwargs):
+    base = globals()
+
+    CustomerOrderItemView = kwargs.get('CustomerOrderItemView', base['CustomerOrderItemView'])
     CustomerOrderItemView.defaults(config)
+
+
+def includeme(config):
+    defaults(config)
