@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2019 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -148,12 +148,6 @@ class ExportMasterView(MasterView):
             obj.created_by = self.request.user
         return obj
 
-    def render_download(self, export, field):
-        path = self.get_file_path(export)
-        text = "{} ({})".format(export.filename, self.readable_size(path))
-        url = self.request.route_url('{}.download'.format(self.get_route_prefix()), uuid=export.uuid)
-        return tags.link_to(text, url)
-
     def render_created_by(self, export, field):
         user = export.created_by
         if not user:
