@@ -650,5 +650,12 @@ class RunJobSchema(colander.MappingSchema):
     warnings = colander.SchemaNode(colander.Bool())
 
 
-def includeme(config):
+def defaults(config, **kwargs):
+    base = globals()
+
+    ImportingView = kwargs.get('ImportingView', base['ImportingView'])
     ImportingView.defaults(config)
+
+
+def includeme(config):
+    defaults(config)
