@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2020 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -189,5 +189,12 @@ class MemberView(MasterView):
             return member.phones[0].number
 
 
-def includeme(config):
+def defaults(config, **kwargs):
+    base = globals()
+
+    MemberView = kwargs.get('MemberView', base['MemberView'])
     MemberView.defaults(config)
+
+
+def includeme(config):
+    defaults(config)
