@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -575,23 +575,36 @@ class RecipientsWidgetBuefy(dfwidget.Widget):
         return field.renderer(template, **values)
 
 
-def includeme(config):
+def defaults(config, **kwargs):
+    base = globals()
 
-    config.add_tailbone_permission('messages', 'messages.list', "List/Search Messages")
+    config.add_tailbone_permission('messages', 'messages.list',
+                                   "List/Search Messages")
 
     # inbox
+    InboxView = kwargs.get('InboxView', base['InboxView'])
     config.add_route('messages.inbox', '/messages/inbox/')
-    config.add_view(InboxView, attr='index', route_name='messages.inbox',
+    config.add_view(InboxView, attr='index',
+                    route_name='messages.inbox',
                     permission='messages.list')
 
     # archive
+    ArchiveView = kwargs.get('ArchiveView', base['ArchiveView'])
     config.add_route('messages.archive', '/messages/archive/')
-    config.add_view(ArchiveView, attr='index', route_name='messages.archive',
+    config.add_view(ArchiveView, attr='index',
+                    route_name='messages.archive',
                     permission='messages.list')
 
     # sent
+    SentView = kwargs.get('SentView', base['SentView'])
     config.add_route('messages.sent', '/messages/sent/')
-    config.add_view(SentView, attr='index', route_name='messages.sent',
+    config.add_view(SentView, attr='index',
+                    route_name='messages.sent',
                     permission='messages.list')
 
+    MessageView = kwargs.get('MessageView', base['MessageView'])
     MessageView.defaults(config)
+
+
+def includeme(config):
+    defaults(config)
