@@ -417,7 +417,9 @@ class PersonView(MasterView):
             'email_type_options': self.get_email_type_options(),
             'max_lengths': self.get_max_lengths(),
             'customers_data': self.get_context_customers(person),
+            'customer_xref_buttons': self.get_customer_xref_buttons(person),
             'members_data': self.get_context_members(person),
+            'member_xref_buttons': self.get_member_xref_buttons(person),
             'employee': employee,
             'employee_data': self.get_context_employee(employee) if employee else {},
             'employee_view_url': self.request.route_url('employees.view', uuid=employee.uuid) if employee else None,
@@ -430,6 +432,22 @@ class PersonView(MasterView):
         template = 'view_profile_buefy' if use_buefy else 'view_profile'
         return self.render_to_response(template, context)
 
+    def get_customer_xref_buttons(self, person):
+        buttons = []
+        for supp in self.iter_view_supplements():
+            if hasattr(supp, 'get_customer_xref_buttons'):
+                buttons.extend(supp.get_customer_xref_buttons(person) or [])
+        buttons = self.normalize_xref_buttons(buttons)
+        return buttons
+
+    def get_member_xref_buttons(self, person):
+        buttons = []
+        for supp in self.iter_view_supplements():
+            if hasattr(supp, 'get_member_xref_buttons'):
+                buttons.extend(supp.get_member_xref_buttons(person) or [])
+        buttons = self.normalize_xref_buttons(buttons)
+        return buttons
+
     def template_kwargs_view_profile(self, **kwargs):
         """
         Stub method so subclass can call `super()` for it.
@@ -859,16 +877,8 @@ class PersonView(MasterView):
         data = dict(self.request.json_body)
 
         # update person address
-        address = person.address
-        if not address:
-            address = person.add_address()
-        address.street = data['street']
-        address.street2 = data['street2']
-        address.city = data['city']
-        address.state = data['state']
-        address.zipcode = data['zipcode']
-
-        self.handler.mark_address_invalid(person, address, data['invalid'])
+        address = self.people_handler.ensure_address(person)
+        self.people_handler.update_address(person, address, **data)
 
         self.Session.flush()
         return {
