@@ -187,27 +187,12 @@ class ProductView(MasterView):
         self.handler = self.products_handler
 
     def query(self, session):
-        user = self.request.user
-        if user and user not in session:
-            user = session.merge(user)
+        query = super(ProductView, self).query(session)
 
-        query = session.query(model.Product)
-        # TODO: was this old `has_permission()` call here for a reason..? hope not..
-        # if not auth.has_permission(session, user, 'products.view_deleted'):
-        if not self.request.has_perm('products.view_deleted'):
+        if not self.has_perm('view_deleted'):
             query = query.filter(model.Product.deleted == False)
 
-        # TODO: This used to be a good idea I thought...but in dev it didn't
-        # seem to make much difference, except with a larger (50K) data set it
-        # totally bogged things down instead of helping...
-        # query = query\
-        #     .options(orm.joinedload(model.Product.brand))\
-        #     .options(orm.joinedload(model.Product.department))\
-        #     .options(orm.joinedload(model.Product.subdepartment))\
-        #     .options(orm.joinedload(model.Product.regular_price))\
-        #     .options(orm.joinedload(model.Product.current_price))\
-        #     .options(orm.joinedload(model.Product.vendor))
-
+        # TODO: surely this is not always needed
         query = query.outerjoin(model.ProductInventory)
 
         return query
@@ -670,7 +655,9 @@ class ProductView(MasterView):
             return ""
         if product.volatile.true_margin is None:
             return ""
-        return "{:0.3f} %".format(product.volatile.true_margin * 100)
+        app = self.get_rattail_app()
+        return app.render_percent(product.volatile.true_margin,
+                                  places=3)
 
     def render_on_hand(self, product, column):
         inventory = product.inventory
@@ -1188,6 +1175,7 @@ class ProductView(MasterView):
         return jsdata
 
     def template_kwargs_view(self, **kwargs):
+        kwargs = super(ProductView, self).template_kwargs_view(**kwargs)
         product = kwargs['instance']
         use_buefy = self.get_use_buefy()
 
@@ -1281,8 +1269,55 @@ class ProductView(MasterView):
             kwargs['vendor_sources'] = self.get_context_vendor_sources(product)
             kwargs['lookup_codes'] = self.get_context_lookup_codes(product)
 
+        kwargs['panel_fields'] = self.get_panel_fields(product)
+
         return kwargs
 
+    def get_panel_fields(self, product):
+        return {
+            'main': self.get_panel_fields_main(product),
+            'flag': self.get_panel_fields_flag(product),
+        }
+
+    def get_panel_fields_main(self, product):
+        key = self.rattail_config.product_key()
+        product_key_field = self.product_key_fields.get(key, key)
+        fields = [
+            product_key_field,
+            'brand',
+            'description',
+            'size',
+            'unit_size',
+            'unit_of_measure',
+            'average_weight',
+            'case_size',
+        ]
+        if product.is_pack_item():
+            fields.extend([
+                'pack_size',
+                'unit',
+                'default_pack',
+            ])
+        elif product.packs:
+            fields.append('packs')
+
+        for supp in self.iter_view_supplements():
+            if hasattr(supp, 'get_panel_fields_main'):
+                fields.extend(supp.get_panel_fields_main(product))
+
+        return fields
+
+    def get_panel_fields_flag(self, product):
+        return [
+            'weighed',
+            'discountable',
+            'special_order',
+            'organic',
+            'not_for_sale',
+            'discontinued',
+            'deleted',
+        ]
+
     def get_context_vendor_sources(self, product):
         app = self.get_rattail_app()
         route_prefix = self.get_route_prefix()
