@@ -223,5 +223,12 @@ class GenerateProjectView(View):
                         renderer='/generate_project.mako')
 
 
-def includeme(config):
+def defaults(config, **kwargs):
+    base = globals()
+
+    GenerateProjectView = kwargs.get('GenerateProjectView', base['GenerateProjectView'])
     GenerateProjectView.defaults(config)
+
+
+def includeme(config):
+    defaults(config)
