@@ -408,5 +408,12 @@ class PurchaseView(MasterView):
                         permission='{}.receiving_worksheet'.format(permission_prefix))
 
 
-def includeme(config):
+def defaults(config, **kwargs):
+    base = globals()
+
+    PurchaseView = kwargs.get('PurchaseView', base['PurchaseView'])
     PurchaseView.defaults(config)
+
+
+def includeme(config):
+    defaults(config)
