@@ -377,5 +377,12 @@ class NewCostingBatch(colander.Schema):
                                    validator=valid_workflow)
 
 
-def includeme(config):
+def defaults(config, **kwargs):
+    base = globals()
+
+    CostingBatchView = kwargs.get('CostingBatchView', base['CostingBatchView'])
     CostingBatchView.defaults(config)
+
+
+def includeme(config):
+    defaults(config)
