@@ -527,5 +527,12 @@ class OrderingBatchView(PurchasingBatchView):
                                        "Download {} as Excel".format(model_title))
 
 
-def includeme(config):
+def defaults(config, **kwargs):
+    base = globals()
+
+    OrderingBatchView = kwargs.get('OrderingBatchView', base['OrderingBatchView'])
     OrderingBatchView.defaults(config)
+
+
+def includeme(config):
+    defaults(config)
