@@ -46,6 +46,7 @@ from pyramid import httpexceptions
 from webhelpers2.html import tags, HTML
 
 from tailbone import forms, grids
+from tailbone.util import get_form_data
 from tailbone.views.purchasing import PurchasingBatchView
 
 
@@ -115,6 +116,7 @@ class ReceivingBatchView(PurchasingBatchView):
         'batch_type',           # TODO: ideally would get rid of this one
         'store',
         'vendor',
+        'description',
         'receiving_workflow',
         'truck_dump',
         'truck_dump_children_first',
@@ -125,6 +127,7 @@ class ReceivingBatchView(PurchasingBatchView):
         'invoice_parser_key',
         'department',
         'purchase',
+        'params',
         'vendor_email',
         'vendor_fax',
         'vendor_contact',
@@ -137,7 +140,6 @@ class ReceivingBatchView(PurchasingBatchView):
         'invoice_number',
         'invoice_total',
         'invoice_total_calculated',
-        'description',
         'notes',
         'created',
         'created_by',
@@ -646,6 +648,8 @@ class ReceivingBatchView(PurchasingBatchView):
             if 'vendor_uuid' in self.request.matchdict:
                 kwargs['vendor_uuid'] = self.request.matchdict['vendor_uuid']
 
+        # TODO: ugh should just have workflow and no batch_type
+        kwargs['receiving_workflow'] = batch_type
         if batch_type == 'from_scratch':
             kwargs.pop('truck_dump_batch', None)
             kwargs.pop('truck_dump_batch_uuid', None)
@@ -715,6 +719,16 @@ class ReceivingBatchView(PurchasingBatchView):
 
         return breakdown
 
+    def allow_edit_catalog_unit_cost(self, batch):
+        return (not batch.executed
+                and self.has_perm('edit_row')
+                and self.batch_handler.allow_receiving_edit_catalog_unit_cost())
+
+    def allow_edit_invoice_unit_cost(self, batch):
+        return (not batch.executed
+                and self.has_perm('edit_row')
+                and self.batch_handler.allow_receiving_edit_invoice_unit_cost())
+
     def template_kwargs_view(self, **kwargs):
         kwargs = super(ReceivingBatchView, self).template_kwargs_view(**kwargs)
         batch = kwargs['instance']
@@ -739,6 +753,9 @@ class ReceivingBatchView(PurchasingBatchView):
                     data=breakdown,
                     columns=['title', 'count'])
 
+        kwargs['allow_edit_catalog_unit_cost'] = self.allow_edit_catalog_unit_cost(batch)
+        kwargs['allow_edit_invoice_unit_cost'] = self.allow_edit_invoice_unit_cost(batch)
+
         return kwargs
 
     def get_context_credits(self, row):
@@ -933,6 +950,7 @@ class ReceivingBatchView(PurchasingBatchView):
 
     def configure_row_grid(self, g):
         super(ReceivingBatchView, self).configure_row_grid(g)
+        use_buefy = self.get_use_buefy()
         batch = self.get_instance()
 
         # vendor_code
@@ -943,14 +961,24 @@ class ReceivingBatchView(PurchasingBatchView):
         if (self.handler.has_purchase_order(batch)
             or self.handler.has_invoice_file(batch)):
             g.remove('catalog_unit_cost')
-
-        # po_unit_cost
-        if self.handler.has_invoice_file(batch):
-            g.remove('po_unit_cost')
+        elif use_buefy and self.allow_edit_catalog_unit_cost(batch):
+            g.set_raw_renderer('catalog_unit_cost', self.render_catalog_unit_cost)
+            g.set_click_handler('catalog_unit_cost',
+                                'catalogUnitCostClicked(props.row)')
 
         # invoice_unit_cost
-        if not self.handler.has_invoice_file(batch):
+        if use_buefy and self.allow_edit_invoice_unit_cost(batch):
+            g.set_raw_renderer('invoice_unit_cost', self.render_invoice_unit_cost)
+            g.set_click_handler('invoice_unit_cost',
+                                'invoiceUnitCostClicked(props.row)')
+
+        # nb. only show PO *or* invoice cost; prefer the latter unless
+        # we have a PO and no invoice
+        if (self.batch_handler.has_purchase_order(batch)
+            and not self.batch_handler.has_invoice_file(batch)):
             g.remove('invoice_unit_cost')
+        else:
+            g.remove('po_unit_cost')
 
         # credits
         # note that sorting by credits involves a subquery with group by clause.
@@ -1001,6 +1029,24 @@ class ReceivingBatchView(PurchasingBatchView):
         else:
             g.set_enum('truck_dump_status', model.PurchaseBatchRow.STATUS)
 
+    def render_catalog_unit_cost(self):
+        return HTML.tag('receiving-cost-editor', **{
+            'field': 'catalog_unit_cost',
+            'v-model': 'props.row.catalog_unit_cost',
+            ':ref': "'catalogUnitCost_' + props.row.uuid",
+            ':row': 'props.row',
+            '@input': 'catalogCostConfirmed',
+        })
+
+    def render_invoice_unit_cost(self):
+        return HTML.tag('receiving-cost-editor', **{
+            'field': 'invoice_unit_cost',
+            'v-model': 'props.row.invoice_unit_cost',
+            ':ref': "'invoiceUnitCost_' + props.row.uuid",
+            ':row': 'props.row',
+            '@input': 'invoiceCostConfirmed',
+        })
+
     def row_grid_extra_class(self, row, i):
         css_class = super(ReceivingBatchView, self).row_grid_extra_class(row, i)
 
@@ -1479,6 +1525,14 @@ class ReceivingBatchView(PurchasingBatchView):
         super(ReceivingBatchView, self).configure_row_form(f)
         batch = self.get_instance()
 
+        # when viewing a row which has no product reference, enable
+        # the 'upc' field to help with troubleshooting
+        # TODO: this maybe should be optional..?
+        if self.viewing and 'upc' not in f:
+            row = self.get_row_instance()
+            if not row.product:
+                f.append('upc')
+
         # allow input for certain fields only; all others are readonly
         mutable = [
             'invoice_unit_cost',
@@ -1782,10 +1836,10 @@ class ReceivingBatchView(PurchasingBatchView):
 
     def update_row_cost(self):
         """
-        AJAX view for updating the invoice (actual) unit cost for a row.
+        AJAX view for updating various cost fields in a data row.
         """
         batch = self.get_instance()
-        data = dict(self.request.POST)
+        data = dict(get_form_data(self.request))
 
         # validate row
         uuid = data.get('row_uuid')
@@ -1931,6 +1985,12 @@ class ReceivingBatchView(PurchasingBatchView):
             {'section': 'rattail.batch',
              'option': 'purchase.receiving.should_autofix_invoice_case_vs_unit',
              'type': bool},
+            {'section': 'rattail.batch',
+             'option': 'purchase.receiving.allow_edit_catalog_unit_cost',
+             'type': bool},
+            {'section': 'rattail.batch',
+             'option': 'purchase.receiving.allow_edit_invoice_unit_cost',
+             'type': bool},
 
             # mobile interface
             {'section': 'rattail.batch',
@@ -2074,5 +2134,12 @@ class DeclareCreditForm(colander.MappingSchema):
                                           missing=colander.null)
 
 
-def includeme(config):
+def defaults(config, **kwargs):
+    base = globals()
+
+    ReceivingBatchView = kwargs.get('ReceivingBatchView', base['ReceivingBatchView'])
     ReceivingBatchView.defaults(config)
+
+
+def includeme(config):
+    defaults(config)
