@@ -180,7 +180,11 @@ class RoleView(PrincipalMasterView):
         f.set_validator('name', self.unique_name)
 
         # adminish
-        if not self.request.is_admin:
+        if self.request.is_admin:
+            f.set_helptext('adminish',
+                           "If checked, only Administrators may add/remove "
+                           "users for the role.")
+        else:
             f.remove('adminish')
 
         # session_timeout
@@ -529,5 +533,12 @@ class PermissionsWidget(dfwidget.Widget):
         return field.renderer(template, **values)
 
 
-def includeme(config):
+def defaults(config, **kwargs):
+    base = globals()
+
+    RoleView = kwargs.get('RoleView', base['RoleView'])
     RoleView.defaults(config)
+
+
+def includeme(config):
+    defaults(config)
