@@ -310,6 +310,15 @@ class AppSettingsView(View):
                         permission='settings.edit')
 
 
-def includeme(config):
+def defaults(config, **kwargs):
+    base = globals()
+
+    AppSettingsView = kwargs.get('AppSettingsView', base['AppSettingsView'])
     AppSettingsView.defaults(config)
+
+    SettingView = kwargs.get('SettingView', base['SettingView'])
     SettingView.defaults(config)
+
+
+def includeme(config):
+    defaults(config)
