@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2018 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -212,5 +212,12 @@ class ScheduleView(TimeSheetView):
                         permission='schedule.print')
 
 
-def includeme(config):
+def defaults(config, **kwargs):
+    base = globals()
+
+    ScheduleView = kwargs.get('ScheduleView', base['ScheduleView'])
     ScheduleView.defaults(config)
+
+
+def includeme(config):
+    defaults(config)
