@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -121,5 +121,12 @@ class StoreView(MasterView):
 StoresView = StoreView
 
 
-def includeme(config):
+def defaults(config, **kwargs):
+    base = globals()
+
+    StoreView = kwargs.get('StoreView', base['StoreView'])
     StoreView.defaults(config)
+
+
+def includeme(config):
+    defaults(config)
