@@ -76,5 +76,12 @@ class TableView(MasterView):
 TablesView = TableView
 
 
-def includeme(config):
+def defaults(config, **kwargs):
+    base = globals()
+
+    TableView = kwargs.get('TableView', base['TableView'])
     TableView.defaults(config)
+
+
+def includeme(config):
+    defaults(config)
