@@ -30,7 +30,7 @@ import six
 
 from rattail.time import localtime
 
-from webhelpers2.html import HTML
+from webhelpers2.html import HTML, tags
 
 from tailbone.db import Session, TrainwreckSession, ExtraTrainwreckSessions
 from tailbone.views import MasterView
@@ -91,6 +91,7 @@ class TransactionView(MasterView):
         'shopper_id',
         'shopper_name',
         'shopper_level_number',
+        'custorder_xref_markers',
         'subtotal',
         'discounted_subtotal',
         'tax',
@@ -127,6 +128,7 @@ class TransactionView(MasterView):
     ]
 
     row_form_fields = [
+        'transaction',
         'sequence',
         'item_type',
         'item_scancode',
@@ -136,6 +138,7 @@ class TransactionView(MasterView):
         'subdepartment_number',
         'subdepartment_name',
         'description',
+        'custorder_item_xref',
         'unit_quantity',
         'subtotal',
         'discounts',
@@ -196,6 +199,9 @@ class TransactionView(MasterView):
         f.set_type('total', 'currency')
         f.set_type('patronage', 'currency')
 
+        # custorder_xref_markers
+        f.set_renderer('custorder_xref_markers', self.render_custorder_xref_markers)
+
         # label overrides
         f.set_label('system_id', "System ID")
         f.set_label('terminal_id', "Terminal")
@@ -203,6 +209,45 @@ class TransactionView(MasterView):
         f.set_label('customer_id', "Customer ID")
         f.set_label('shopper_id', "Shopper ID")
 
+    def render_custorder_xref_markers(self, txn, field):
+        markers = getattr(txn, field)
+        if not markers:
+            return
+
+        route_prefix = self.get_route_prefix()
+        factory = self.get_grid_factory()
+        use_buefy = self.get_use_buefy()
+
+        g = factory(
+            key='{}.custorder_xref_markers'.format(route_prefix),
+            data=[] if use_buefy else txn.custorder_xref_markers,
+            columns=['custorder_xref', 'custorder_item_xref'],
+            request=self.request)
+
+        if use_buefy:
+            return HTML.literal(
+                g.render_buefy_table_element(data_prop='custorderXrefMarkersData'))
+        else:
+            return HTML.literal(g.render_grid())
+
+    def template_kwargs_view(self, **kwargs):
+        kwargs = super(TransactionView, self).template_kwargs_view(**kwargs)
+
+        use_buefy = self.get_use_buefy()
+        if use_buefy:
+            form = kwargs['form']
+            if 'custorder_xref_markers' in form:
+                txn = kwargs['instance']
+                markers = []
+                for marker in txn.custorder_xref_markers:
+                    markers.append({
+                        'custorder_xref': marker.custorder_xref,
+                        'custorder_item_xref': marker.custorder_item_xref,
+                    })
+                kwargs['custorder_xref_markers_data'] = markers
+
+        return kwargs
+
     def get_row_data(self, transaction):
         return self.Session.query(self.model_row_class)\
                            .filter(self.model_row_class.transaction == transaction)
@@ -227,9 +272,15 @@ class TransactionView(MasterView):
         if row.void:
             return 'warning'
 
+    def get_row_instance_title(self, instance):
+        return "Trainwreck Line Item"
+
     def configure_row_form(self, f):
         super(TransactionView, self).configure_row_form(f)
 
+        # transaction
+        f.set_renderer('transaction', self.render_transaction)
+
         # quantity fields
         f.set_type('unit_quantity', 'quantity')
 
@@ -243,6 +294,12 @@ class TransactionView(MasterView):
         # discounts
         f.set_renderer('discounts', self.render_discounts)
 
+    def render_transaction(self, item, field):
+        txn = getattr(item, field)
+        text = six.text_type(txn)
+        url = self.get_action_url('view', txn)
+        return tags.link_to(text, url)
+
     def render_discounts(self, item, field):
         if not item.discounts:
             return
@@ -360,16 +417,18 @@ class TransactionView(MasterView):
 
     def configure_remove_settings(self):
         super(TransactionView, self).configure_remove_settings()
+        app = self.get_rattail_app()
 
-        model = self.model
         names = [
             'trainwreck.db.hide',
             'tailbone.engines.trainwreck.hidden', # deprecated
         ]
-        # nb. we do not use self.Session b/c that points to trainwreck
-        Session.query(model.Setting)\
-               .filter(model.Setting.name.in_(names))\
-               .delete(synchronize_session=False)
+
+        # nb. using thread-local session here; we do not use
+        # self.Session b/c it may not point to Rattail
+        session = Session()
+        for name in names:
+            app.delete_setting(session, name)
 
     @classmethod
     def defaults(cls, config):
