@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -29,5 +29,10 @@ from __future__ import unicode_literals, absolute_import
 from .core import VendorView
 
 
+def defaults(config, **kwargs):
+    from .core import defaults
+    return defaults(config, **kwargs)
+
+
 def includeme(config):
     config.include('tailbone.views.vendors.core')
